@@ -125,6 +125,7 @@ from .type_defs import (
     TableToReloadTypeDef,
     TagTypeDef,
     TestConnectionResponseTypeDef,
+    UpdateSubscriptionsToEventBridgeResponseTypeDef,
 )
 from .waiter import (
     EndpointDeletedWaiter,
@@ -239,6 +240,14 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#cancel_replication_task_assessment_run)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#close)
+        """
+
     def create_endpoint(
         self,
         *,
@@ -1084,6 +1093,17 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#test_connection)
         """
 
+    def update_subscriptions_to_event_bridge(
+        self, *, ForceMove: bool = ...
+    ) -> UpdateSubscriptionsToEventBridgeResponseTypeDef:
+        """
+        Migrates 10 active and enabled Amazon SNS subscriptions at a time and converts
+        them to corresponding Amazon EventBridge rules.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.update_subscriptions_to_event_bridge)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#update_subscriptions_to_event_bridge)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["describe_certificates"]
