@@ -147,6 +147,7 @@ __all__ = (
     "StartReplicationTaskMessageRequestTypeDef",
     "StopReplicationTaskMessageRequestTypeDef",
     "TestConnectionMessageRequestTypeDef",
+    "UpdateSubscriptionsToEventBridgeMessageRequestTypeDef",
     "AddTagsToResourceMessageRequestTypeDef",
     "CreateEventSubscriptionMessageRequestTypeDef",
     "CreateReplicationInstanceMessageRequestTypeDef",
@@ -162,6 +163,7 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "ReloadTablesResponseTypeDef",
     "RunFleetAdvisorLsaAnalysisResponseTypeDef",
+    "UpdateSubscriptionsToEventBridgeResponseTypeDef",
     "SubnetTypeDef",
     "DeleteCertificateResponseTypeDef",
     "DescribeCertificatesResponseTypeDef",
@@ -428,6 +430,7 @@ _OptionalElasticsearchSettingsTypeDef = TypedDict(
     {
         "FullLoadErrorPercentage": int,
         "ErrorRetryDuration": int,
+        "UseNewMappingType": bool,
     },
     total=False,
 )
@@ -536,6 +539,7 @@ MicrosoftSQLServerSettingsTypeDef = TypedDict(
         "UseThirdPartyBackupDevice": bool,
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
+        "TrimSpaceInChar": bool,
     },
     total=False,
 )
@@ -649,6 +653,7 @@ OracleSettingsTypeDef = TypedDict(
         "SecretsManagerSecretId": str,
         "SecretsManagerOracleAsmAccessRoleArn": str,
         "SecretsManagerOracleAsmSecretId": str,
+        "TrimSpaceInChar": bool,
     },
     total=False,
 )
@@ -674,6 +679,7 @@ PostgreSQLSettingsTypeDef = TypedDict(
         "PluginName": PluginNameValueType,
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
+        "TrimSpaceInChar": bool,
     },
     total=False,
 )
@@ -780,6 +786,8 @@ S3SettingsTypeDef = TypedDict(
         "MaxFileSize": int,
         "Rfc4180": bool,
         "DatePartitionTimezone": str,
+        "AddTrailingPaddingCharacter": bool,
+        "ExpectedBucketOwner": str,
     },
     total=False,
 )
@@ -1568,6 +1576,14 @@ TestConnectionMessageRequestTypeDef = TypedDict(
     },
 )
 
+UpdateSubscriptionsToEventBridgeMessageRequestTypeDef = TypedDict(
+    "UpdateSubscriptionsToEventBridgeMessageRequestTypeDef",
+    {
+        "ForceMove": bool,
+    },
+    total=False,
+)
+
 AddTagsToResourceMessageRequestTypeDef = TypedDict(
     "AddTagsToResourceMessageRequestTypeDef",
     {
@@ -1797,6 +1813,14 @@ RunFleetAdvisorLsaAnalysisResponseTypeDef = TypedDict(
     },
 )
 
+UpdateSubscriptionsToEventBridgeResponseTypeDef = TypedDict(
+    "UpdateSubscriptionsToEventBridgeResponseTypeDef",
+    {
+        "Result": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 SubnetTypeDef = TypedDict(
     "SubnetTypeDef",
     {
